@@ -130,23 +130,34 @@ def killTaskProcess(process_name: str):
 
 def doKeepAliveJob(path: str, cmd: str, task_name: str):
     """
-    间隔任务
+    保活任务
     :param path: 文件路径
     :param cmd: 命令
     :param task_name: 程序在任务管理器中的名称
     :return:
     """
-    if task_name.endswith('.py'):
-        index = task_name.rfind('.')
-        key = task_name[:index]
+    if cmd.startswith('python ') or cmd.startswith('uvicorn '):
+        index = cmd.find(' ')+1
+        task_name = cmd[index:]
         process_detail = execCmd(
-            f'wmic process where caption="python.exe" get commandline,processid|find "{key}"')
-    elif task_name.endswith('.exe'):
+            f'wmic process where caption="python.exe" get commandline,processid|find "{task_name}"')
+    elif cmd.endswith('.exe'):
         process_detail = execCmd(f'wmic process where caption="{task_name}" get commandline,processid')
     else:
-        logHandler.error('程序名不正确，需要带文件后缀，例如：clion.exe,TQ.py')
+        logHandler.error('无法识别程序名，请检查命令格式')
         return
 
+    # if task_name.endswith('.py'):
+    #     index = task_name.rfind('.')
+    #     key = task_name[:index]
+    #     process_detail = execCmd(
+    #         f'wmic process where caption="python.exe" get commandline,processid|find "{key}"')
+    # elif task_name.endswith('.exe'):
+    #     process_detail = execCmd(f'wmic process where caption="{task_name}" get commandline,processid')
+    # else:
+    #     logHandler.error('程序名不正确，需要带文件后缀，例如：clion.exe,TQ.py')
+    #     return
+
     now_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
     # logHandler.info(process_detail)
     if len(process_detail) != 0:
@@ -173,9 +184,10 @@ def doCronJob(path, cmd):
         if len(path) != 0:
             os.chdir(path)  # 在父进程中切换工作目录，否则子进程找不到文件，或者os.system('cd path-to-repo && svn ci')
         cmd = cmd.strip()
-        if cmd.startswith('python') or cmd.endswith('.bat'):
-            os.system(f'start {cmd}')
-        elif cmd.lower().startswith('taskkill'):
+        # if cmd.startswith('python') or cmd.startswith('uvicorn') or cmd.endswith('.bat'):
+        #     os.system(f'start {cmd}')
+        # elif
+        if cmd.lower().startswith('taskkill'):
             cmd_param = cmd.split(' ')
             if len(cmd_param) != 2:
                 if len(path) != 0:
@@ -184,7 +196,7 @@ def doCronJob(path, cmd):
                 return
             killTaskProcess(cmd_param[1])
         else:
-            os.system(f'{cmd}')
+            os.system(f'start {cmd}')
         if len(path) != 0:
             os.chdir(current_dir)
     except Exception as e:
@@ -265,5 +277,6 @@ def doJobs(path: str):
 
 
 if __name__ == '__main__':
-    killTaskProcess('webgate2.py')
+    # killTaskProcess('webgate2.py')
     # doJobs(path='../conf/task.conf')
+    doJobs(path='./task.conf')
