@@ -31,11 +31,13 @@ class CronJobDialog(tk.Toplevel):
         self.desc = tk.StringVar()
         self.enable = tk.IntVar()
 
+        self.day_of_week.set('0-6')
+
         if data is not None:
             self.name.set(data.get('name') if data.get('name') is not None else '')
             self.exec_cmd.set(data.get('exec_cmd') if data.get('exec_cmd') is not None else '')
             self.exec_path.set(data.get('exec_path') if data.get('exec_path') is not None else '')
-            self.day_of_week.set(data.get('day_of_week') if data.get('day_of_week') is not None else '')
+            self.day_of_week.set(data.get('day_of_week') if data.get('day_of_week') is not None else '0-6')
             self.hour.set(data.get('hour') if data.get('hour') is not None else 0)
             self.minute.set(data.get('minute') if data.get('minute') is not None else 0)
             self.second.set(data.get('second') if data.get('second') is not None else 0)
@@ -175,8 +177,8 @@ class IntervalJobDialog(tk.Toplevel):
         tk.Label(row1, text='间隔触发(秒)：', width=labelzize, anchor=NW, font=('Times', 10)).grid(row=3, column=0)
         tk.Entry(row1, textvariable=self.second, width=entrysize, font=('Times', 10)).grid(row=3, column=1)
 
-        tk.Label(row1, text='任务名：', width=labelzize, anchor=NW, font=('Times', 10)).grid(row=4, column=0)
-        tk.Entry(row1, textvariable=self.task_name, width=entrysize, font=('Times', 10)).grid(row=4, column=1)
+        # tk.Label(row1, text='任务名：', width=labelzize, anchor=NW, font=('Times', 10)).grid(row=4, column=0)
+        # tk.Entry(row1, textvariable=self.task_name, width=entrysize, font=('Times', 10)).grid(row=4, column=1)
 
         tk.Label(row1, text='描述：', width=labelzize, anchor=NW, font=('Times', 10)).grid(row=5, column=0)
         tk.Entry(row1, textvariable=self.desc, width=entrysize, font=('Times', 10)).grid(row=5, column=1)
@@ -205,7 +207,7 @@ class IntervalJobDialog(tk.Toplevel):
         self.jobdic['exec_path'] = self.exec_path.get() if self.exec_path.get() is not None else ''
         self.jobdic['job_type'] = 3  # 1 定时任务 3 间隔任务
         self.jobdic['second'] = self.second.get() if self.second.get() is not None else 5
-        self.jobdic['task_name'] = self.task_name.get() if self.task_name.get() is not None else ''
+        # self.jobdic['task_name'] = self.task_name.get() if self.task_name.get() is not None else ''
         self.jobdic['desc'] = self.desc.get() if self.desc.get() is not None else ''
         self.jobdic['enable'] = self.enable.get() if self.enable.get() is not None else 1
         # self.parent
@@ -287,16 +289,22 @@ class SchedulerUI(Frame):
         self.initList()
 
         # # 右侧Frame帧第二行添加控制按钮
-        # self.frm_log = ttk.Frame(self.frm_right, relief=RIDGE)  # 四个方向拉伸, style="www.TFrame"
-        # self.frm_log.grid(row=1, column=0, sticky=NSEW)
-        #
-        # tk.Label(self.frm_log, text='运行中任务：', anchor=NW).grid(row=0, column=0)
-        # self.log_data_Text = Text(self.frm_log, height=10)  # 日志框
-        # self.log_data_Text.grid(row=1, column=0, sticky=NSEW)
-        #
-        # # "insert" 索引表示插入光标当前的位置
-        # self.log_data_Text.insert("insert", "I love ")
-        # self.log_data_Text.insert("end", "Python.com!")
+        self.frm_log = ttk.Frame(self.frm_right, relief=RIDGE)  # 四个方向拉伸, style="www.TFrame"
+        self.frm_log.grid(row=1, column=0, sticky=NSEW)
+
+        msg = '注意：\n' \
+              '1) 任务名必须唯一。\n' \
+              '2) “taskkill+文件名.后缀” 杀死进程。任务只支持python跟exe等单执行文件。\n' \
+              '3) 循环任务用于保活程序时只支持python跟exe等单窗口或单进程文件，就是一个文件一个操作。文件里面另开运行窗口就会被监控忽略。\n' \
+              '4) 任务配置文件使用utf-8编码，不支持中文字符。\n' \
+              '5) 除了执行python命令跟bat文件是启动单独窗口之外其它的命令都在父窗口执行，如果要单独窗口可以在命令前添加‘start’指令。'
+
+        # tk.Label(self.frm_log, text=msg, anchor=NW).grid(row=0, column=0)
+        self.log_data_Text = Text(self.frm_log, height=10)  # 日志框
+        self.log_data_Text.grid(row=1, column=0, sticky=NSEW)
+        # "insert" 索引表示插入光标当前的位置
+        # self.log_data_Text.insert("insert", msg)
+        self.log_data_Text.insert("end", msg)
         #
         # self.frm_log = ttk.Frame(self.frm_right, relief=RIDGE)  # 四个方向拉伸, style="www.TFrame"
         # self.frm_log.grid(row=1, column=2, sticky=NSEW)
@@ -333,7 +341,7 @@ class SchedulerUI(Frame):
         scrollbar = Scrollbar(self.frm_list)
         scrollbar.pack(side=RIGHT, fill=Y)
 
-        title = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11']
+        title = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10']
         self.treeview = ttk.Treeview(self.frm_list, columns=title,
                                      yscrollcommand=scrollbar.set,
                                      show='headings', )
@@ -345,9 +353,9 @@ class SchedulerUI(Frame):
         self.treeview.column('6', width=20, anchor='center')
         self.treeview.column('7', width=20, anchor='center')
         self.treeview.column('8', width=20, anchor='center')
+        # self.treeview.column('9', width=200, anchor='w')
         self.treeview.column('9', width=200, anchor='w')
-        self.treeview.column('10', width=200, anchor='w')
-        self.treeview.column('11', width=20, anchor='center')
+        self.treeview.column('10', width=20, anchor='center')
 
         self.treeview.heading('1', text='名称')
         self.treeview.heading('2', text='命令')
@@ -357,9 +365,9 @@ class SchedulerUI(Frame):
         self.treeview.heading('6', text='时')
         self.treeview.heading('7', text='分')
         self.treeview.heading('8', text='秒')
-        self.treeview.heading('9', text='任务名')
-        self.treeview.heading('10', text='描述')
-        self.treeview.heading('11', text='激活')
+        # self.treeview.heading('9', text='任务名')
+        self.treeview.heading('9', text='描述')
+        self.treeview.heading('10', text='激活')
 
         scrollbar.config(command=self.treeview.yview)  # 设置Scrollbar组件的command选项为该组件的yview()方法
         self.treeview.pack(fill=BOTH)
@@ -430,7 +438,8 @@ class SchedulerUI(Frame):
                 jobMsg = '无效的类型'
                 print(f'任务:{name} 中无效的类型：{jobtype}')
 
-            rst = [name, cmd, path, jobMsg, week, hour, minute, second, task_name, desc, enable]
+            # rst = [name, cmd, path, jobMsg, week, hour, minute, second, task_name, desc, enable]
+            rst = [name, cmd, path, jobMsg, week, hour, minute, second, desc, enable]
             self.treeview.insert('', 'end', values=rst)
 
     def addIntervalJob(self):
